package com.denachina.pickle.ui;

import android.app.Activity;
import android.app.Dialog;
import android.content.Context;
import android.os.Bundle;
import android.text.TextUtils;
import android.util.Log;
import android.view.View;
import android.view.ViewGroup;
import android.widget.AdapterView;
import android.widget.BaseAdapter;
import android.widget.GridView;
import android.widget.TextView;

import com.denachina.lcm.sdk.LCMError;
import com.denachina.lcm.sdk.bank.VCBundle;
import com.denachina.lcm.sdk.bank.Wallet;
import com.denachina.pickle.util.ResourceManager;
import com.denachina.pickle.util.Utils;

import java.util.List;

/**
 * Created by he.b.wang on 16/5/4.
 */
public class PurchaseDialog extends Dialog {

    private static final String TAG = PurchaseDialog.class.getSimpleName();

    private TextView paidTextView;
    private TextView freeTextView;
    private GridView mGridView;
    private View balanceView;
    private GridViewAdapter adapter;
    private List<VCBundle> vcBundleList;
    private String paid, free;
    private AdapterView.OnItemClickListener onItemClickListener;
    private ResourceManager R;

    public PurchaseDialog(Context context) {
        super(context, android.R.style.Theme_Black_NoTitleBar);
        R = ResourceManager.getInstance(context);
        setOwnerActivity((Activity)context);
    }

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        initView();
    }

    private void initView() {
        View rootView = getLayoutInflater().inflate(R.getLayoutForId("dialog_purchase_layout"), null);
        ViewGroup.LayoutParams layoutParams = new ViewGroup.LayoutParams(ViewGroup.LayoutParams.MATCH_PARENT, ViewGroup.LayoutParams.MATCH_PARENT);
        setContentView(rootView, layoutParams);
        balanceView = rootView.findViewById(R.getId("balance_view"));
        mGridView = (GridView) rootView.findViewById(R.getId("grid_layout"));
        paidTextView = (TextView) rootView.findViewById(R.getId("paid_txt"));
        freeTextView = (TextView) rootView.findViewById(R.getId("free_txt"));
        adapter = new GridViewAdapter();
        mGridView.setAdapter(adapter);
        findViewById(R.getId("back")).setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                PurchaseDialog.this.dismiss();
            }
        });
        Log.d(TAG,"free:"+free+" , paid:"+paid);
        setFreeText(free);
        setPaidText(paid);
        setItemOnClick(onItemClickListener);
    }

    public void setItemOnClick(AdapterView.OnItemClickListener onItemClickListener) {
        this.onItemClickListener = onItemClickListener;
        if (mGridView != null) {
            mGridView.setOnItemClickListener(onItemClickListener);
        }
    }

    public void setPaidText(String paid) {
        this.paid = paid;
        if (paidTextView != null) {
            if(TextUtils.isEmpty(paid)) {
                paidTextView.setText("0");
            } else {
                paidTextView.setText(paid);
            }
        }
    }

    public void setFreeText(String free) {
        this.free = free;
        if (freeTextView != null) {
            if(TextUtils.isEmpty(free)) {
                freeTextView.setText("0");
            } else {
                freeTextView.setText(free);
            }
        }
    }

    public void putVCBundleList(List<VCBundle> vcBundleList) {
        this.vcBundleList = vcBundleList;
        if (adapter != null) {
            adapter.notifyDataSetChanged();
        }
    }

    class GridViewAdapter extends BaseAdapter {

        @Override
        public int getCount() {
            return vcBundleList == null ? 0 : vcBundleList.size();
        }

        @Override
        public Object getItem(int position) {
            return vcBundleList.get(position);
        }

        @Override
        public long getItemId(int position) {
            return 0;
        }

        @Override
        public View getView(int position, View convertView, ViewGroup parent) {
            if (convertView == null) {
                convertView = new ProductItemView(getContext());
            }
            ((ProductItemView)convertView).setVcBundle((VCBundle) getItem(position));
            return convertView;
        }
    }

    /**
     * 调用此接口,获得是否显示L币余额,
     * 根据isShow的结果,绘制余额UI
     * @param activity
     */
    public void setBalanceVisible(final Activity activity){
        Log.i(TAG, "setBalanceVisible");
        Wallet.isShowBalance(activity, new Wallet.OnShowBalanceCallback() {
            @Override
            public void onComplete(Wallet wallet, boolean isShow, LCMError error) {
                Log.i(TAG, "setBalanceVisible onComplete.");
                if(error != null) {
                    Log.i(TAG, "setBalanceVisible failed.");
                    Utils.showLongToastOnUiThread(activity, error.getErrorMsg());
                }else {
                    Log.i(TAG, "setBalanceVisible success.");
                    setPaidText(String.valueOf(wallet.getPaidBalance()));
                    setFreeText(String.valueOf(wallet.getFreeBalance()));
                    if(isShow){
                        balanceView.setVisibility(View.VISIBLE);
                        Log.i(TAG, "setBalanceVisible success >> showBalanceButton");
                    }else {
                        balanceView.setVisibility(View.GONE);
                        Log.i(TAG, "setBalanceVisible success >> do not showBalanceButton");
                    }
                }
            }
        });
    }

    public void setFree(String free){
        this.free = free;
    }

    public void setPaid(String paid){
        this.paid = paid;
    }
}
